# Offline mode

The music player has an 'offline mode'. In this mode, the application:

- Does not make any connections to the internet.
- Does not transcode audio or images, always uses high quality opus audio and webp images. This means that Safari is not supported.
- Does not use a local music library, but synchronizes from a main music server.
- Keeps a local history, which it submits to the main music server when an internet connection is available.

![Music player in dashboard](tyrone_music.jpg)

## Installation

To install the music player in offline mode, follow the [standard installation instructions](./installation.md) with one change; add the command line flag `--offline` or environment variable `MUSIC_OFFLINE_MODE: 1`.

## Synchronization

To synchronize history and music, visit: http://localhost:8080/offline/sync

## Reset

To clear settings (like server URL, username, password):
```
sqlite3 data/offline.db 'DELETE FROM settings;'
```

To clear downloaded music data (this should never be needed):
```
sqlite3 data/offline.db 'DELETE FROM content;'
sqlite3 data/music.db 'PRAGMA foreign_keys = on; DELETE FROM playlist;'
```

## Start on boot

On a Linux system, you can create a systemd user service to start the music server on boot.

Create a service file, e.g. `.config/systemd/user/music.service` with the following contents:

```
[Unit]
Description=Music Player

[Service]
ExecStart=/home/youruser/.local/bin/raphson-mp --offline --data-dir /home/youruser/music-data/data start
Restart=always

[Install]
WantedBy=default.target
```

You might need to change the path to the `raphson-mp` executable or the data directory.

Reload: `systemctl --user daemon-reload`

Enable and start the service: `systemctl --user enable --now music`
