export const MusicEvent = {
    METADATA_CHANGE: 'metadata_change', // Tracks or playlists have been changed, added, or removed. Any HTML with playlist/track info should be updated. Track with updated metadata may be provided as parameter to the callable.
    TRACK_CHANGE: 'track_change', // Track that is playing changed (skipped to next or previous track). New DownloadedTrack is provided as parameter to the callable
    SETTINGS_LOADED: 'settings_loaded',
    PLAYLIST_CHANGE: `playlist_change` // Active playlists changed
};

class EventBus {
    /** @type{Object.<string, Array<Function>>} */
    listeners;

    constructor() {
        this.listeners = {};

        for (const event of Object.values(MusicEvent)) {
            this.listeners[event] = [];
        }
    }

    /**
     * @param {string} name
     * @param callable
     */
    subscribe(name, callable) {
        this.listeners[name].push(callable);
    }

    /**
     * @param {string} name
     * @param {...any} params
     */
    publish(name, ...params) {
        for (const callable of this.listeners[name]) {
            try {
                callable(...params);
            } catch (error) {
                console.error(error);
                window.dispatchEvent(new Event("error", error));
            }
        }
    }
}

export const eventBus = new EventBus();
